From 20916be316d1c0a35970f0a2806f18043497a602 Mon Sep 17 00:00:00 2001
From: Jim Meyering <meyering@redhat.com>
Date: Tue, 7 Jun 2011 19:48:16 +0200
Subject: [PATCH libguestfs 1/4] build: update to latest gnulib

* .gnulib: Update submodule to latest.
* daemon/m4/gnulib-cache.m4: Regenerate.
---
 .gnulib                   |    2 +-
 daemon/m4/gnulib-cache.m4 |    8 ++++----
 m4/.gitignore             |   21 +++++++++++++++++++++
 3 files changed, 26 insertions(+), 5 deletions(-)

diff --git a/.gnulib b/.gnulib
index 74d5093..fba3245 160000
--- a/.gnulib
+++ b/.gnulib
@@ -1 +1 @@
-Subproject commit 74d509383fe30bb5511a978b52e4f8ecae37826b
+Subproject commit fba324553f05901eebdd0884ffff74b04a06704a
diff --git a/daemon/m4/gnulib-cache.m4 b/daemon/m4/gnulib-cache.m4
index f026cb3..27e37ee 100644
--- a/daemon/m4/gnulib-cache.m4
+++ b/daemon/m4/gnulib-cache.m4
@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2010 Free Software Foundation, Inc.
+# Copyright (C) 2002-2011 Free Software Foundation, Inc.
 #
 # This file is free software, distributed under the terms of the GNU
 # General Public License.  As a special exception to the GNU General
@@ -10,12 +10,12 @@
 #
 # This file represents the specification of how gnulib-tool is used.
 # It acts as a cache: It is written and read by gnulib-tool.
-# In projects using CVS, this file is meant to be stored in CVS,
-# like the configure.ac and various Makefile.am files.
+# In projects that use version control, this file is meant to be put under
+# version control, like the configure.ac and various Makefile.am files.


 # Specification in the form of a command-line invocation:
-#   gnulib-tool --import --dir=. --lib=libgnu --source-base=lib --m4-base=m4 --doc-base=doc --tests-base=tests --aux-dir=build-aux --with-tests --no-libtool --macro-prefix=gl byteswap c-ctype connect error fsusage futimens getaddrinfo getline glob hash ignore-value manywarnings mkdtemp netdb openat perror pread read-file readlink select sleep socket strchrnul strndup symlinkat sys_select sys_wait vasprintf warnings
+#   gnulib-tool --import --dir=. --lib=libgnu --source-base=lib --m4-base=m4 --doc-base=doc --tests-base=tests --aux-dir=build-aux --with-tests --no-conditional-dependencies --no-libtool --macro-prefix=gl byteswap c-ctype connect error fsusage futimens getaddrinfo getline glob hash ignore-value manywarnings mkdtemp netdb openat perror pread read-file readlink select sleep socket strchrnul strndup symlinkat sys_select sys_wait vasprintf warnings

 # Specification in the form of a few gnulib-tool.m4 macro invocations:
 gl_LOCAL_DIR([])
diff --git a/m4/.gitignore b/m4/.gitignore
index 2ab011d..6cc68d9 100644
--- a/m4/.gitignore
+++ b/m4/.gitignore
@@ -178,3 +178,24 @@ xsize.m4
 /quote.m4
 /strtoimax.m4
 /strtoumax.m4
+/btowc.m4
+/configmake.m4
+/fflush.m4
+/filenamecat.m4
+/fpurge.m4
+/freading.m4
+/fseeko.m4
+/ftell.m4
+/ftello.m4
+/locale_h.m4
+/localename.m4
+/lseek.m4
+/mbtowc.m4
+/read.m4
+/setlocale.m4
+/snprintf.m4
+/socklen.m4
+/sys_uio_h.m4
+/ungetc.m4
+/wcrtomb.m4
+/wctomb.m4
-- 
1.7.6.rc0.293.g40857


From 5f4601faf11e19dffa57c12543cdec529ca8431b Mon Sep 17 00:00:00 2001
From: Jim Meyering <meyering@redhat.com>
Date: Thu, 9 Jun 2011 22:15:52 +0200
Subject: [PATCH libguestfs 2/4] bootstrap: use --libtool

---
 bootstrap |    1 +
 1 files changed, 1 insertions(+), 0 deletions(-)

diff --git a/bootstrap b/bootstrap
index c1712ae..0dd31a9 100755
--- a/bootstrap
+++ b/bootstrap
@@ -84,6 +84,7 @@ $gnulib_tool			\
   --m4-base=m4			\
   --source-base=gnulib/lib	\
   --tests-base=gnulib/tests	\
+  --libtool			\
   --import $modules

 # Disable autopoint and libtoolize, since they were already done above.
-- 
1.7.6.rc0.293.g40857


From e5d07f78978769d421a485d56690b37ef18ef00e Mon Sep 17 00:00:00 2001
From: Jim Meyering <meyering@redhat.com>
Date: Thu, 9 Jun 2011 22:16:29 +0200
Subject: [PATCH libguestfs 3/4] include config.h, even from examples

---
 examples/create_disk.c       |    4 +++-
 examples/virt-dhcp-address.c |    2 ++
 2 files changed, 5 insertions(+), 1 deletions(-)

diff --git a/examples/create_disk.c b/examples/create_disk.c
index f4b9044..fa3c300 100644
--- a/examples/create_disk.c
+++ b/examples/create_disk.c
@@ -1,5 +1,7 @@
 /* Example showing how to create a disk image. */

+#include <config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -7,7 +9,7 @@
 #include <unistd.h>
 #include <guestfs.h>

-int                                                                            
+int
 main (int argc, char *argv[])
 {
   guestfs_h *g;
diff --git a/examples/virt-dhcp-address.c b/examples/virt-dhcp-address.c
index 5b68313..f0ab721 100644
--- a/examples/virt-dhcp-address.c
+++ b/examples/virt-dhcp-address.c
@@ -9,6 +9,8 @@
  * https://rwmj.wordpress.com/2011/03/30/tip-another-way-to-get-the-ip-address-of-a-virtual-machine/
  */

+#include <config.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-- 
1.7.6.rc0.293.g40857


From cab12e8dcace6047d19499805f988637feda168d Mon Sep 17 00:00:00 2001
From: Jim Meyering <meyering@redhat.com>
Date: Thu, 9 Jun 2011 22:17:22 +0200
Subject: [PATCH libguestfs 4/4] examples/Makefile.am: link with libgnu.la for
 use of rpl_getcwd

---
 examples/Makefile.am |    9 ++++++---
 1 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/examples/Makefile.am b/examples/Makefile.am
index b8a2ffe..f12fd1a 100644
--- a/examples/Makefile.am
+++ b/examples/Makefile.am
@@ -35,7 +35,8 @@ create_disk_CFLAGS = \
 	-I$(top_srcdir)/src -I$(top_builddir)/src \
 	$(WARN_CFLAGS) $(WERROR_CFLAGS)
 create_disk_LDADD = \
-	$(top_builddir)/src/libguestfs.la
+	$(top_builddir)/src/libguestfs.la \
+        ../gnulib/lib/libgnu.la

 inspect_vm_SOURCES = inspect_vm.c
 inspect_vm_CFLAGS = \
@@ -43,7 +44,8 @@ inspect_vm_CFLAGS = \
 	-I$(top_srcdir)/src -I$(top_builddir)/src \
 	$(WARN_CFLAGS) $(WERROR_CFLAGS)
 inspect_vm_LDADD = \
-	$(top_builddir)/src/libguestfs.la
+	$(top_builddir)/src/libguestfs.la \
+        ../gnulib/lib/libgnu.la

 virt_dhcp_address_SOURCES = virt-dhcp-address.c
 virt_dhcp_address_CFLAGS = \
@@ -53,7 +55,8 @@ virt_dhcp_address_CFLAGS = \
 	$(HIVEX_CFLAGS)
 virt_dhcp_address_LDADD = \
 	$(HIVEX_LIBS) \
-	$(top_builddir)/src/libguestfs.la
+	$(top_builddir)/src/libguestfs.la \
+        ../gnulib/lib/libgnu.la

 man_MANS = \
 	guestfs-examples.3 \
-- 
1.7.6.rc0.293.g40857

